@@ -65,7 +65,7 @@ static GSList           *gnome_db_model_wrapper_model_get_key_columns  (GnomeDbD
 static void                 gnome_db_model_wrapper_data_model_init (GdaDataModelIface *iface);
 static gint                 gnome_db_model_wrapper_get_n_rows      (GdaDataModel *model);
 static gint                 gnome_db_model_wrapper_get_n_columns   (GdaDataModel *model);
-static GdaDataModelColumnAttributes  *gnome_db_model_wrapper_describe_column (GdaDataModel *model, gint col);
+static GdaColumn  *gnome_db_model_wrapper_describe_column (GdaDataModel *model, gint col);
 static const gchar         *gnome_db_model_wrapper_get_column_title(GdaDataModel *model, gint col);
 static void                 gnome_db_model_wrapper_set_column_title(GdaDataModel *model, gint col, const gchar *title);
 static gint                 gnome_db_model_wrapper_get_column_pos  (GdaDataModel *model, const gchar *title);
@@ -79,9 +79,9 @@ static gboolean             gnome_db_model_wrapper_cancel_changes  (GdaDataModel
 static const GdaRow        *gnome_db_model_wrapper_append_row      (GdaDataModel *model, const GList *values);
 static gboolean             gnome_db_model_wrapper_remove_row      (GdaDataModel *model, const GdaRow *row);
 static gboolean             gnome_db_model_wrapper_update_row      (GdaDataModel *model, const GdaRow *row);
-static gboolean             gnome_db_model_wrapper_append_column   (GdaDataModel *model, const GdaDataModelColumnAttributes *attrs);
+static gboolean             gnome_db_model_wrapper_append_column   (GdaDataModel *model, const GdaColumn *attrs);
 static gboolean             gnome_db_model_wrapper_update_column   (GdaDataModel *model, gint col,
-                                                                 const GdaDataModelColumnAttributes *attrs);
+                                                                 const GdaColumn *attrs);
 static gboolean             gnome_db_model_wrapper_remove_column   (GdaDataModel *model, gint col);
 static void                 gnome_db_model_wrapper_set_notify      (GdaDataModel *model, gboolean do_notify_changes);
 static gboolean             gnome_db_model_wrapper_get_notify      (GdaDataModel *model);
@@ -278,8 +278,7 @@ gnome_db_model_wrapper_new (GnomeDbDict *dict, GdaDataModel *model)
 	GObject   *obj;
 	GnomeDbModelWrapper *wrapper;
 	
-	if (dict)
-		g_return_val_if_fail (dict && IS_GNOME_DB_DICT (dict), NULL);
+	g_return_val_if_fail (!dict || IS_GNOME_DB_DICT (dict), NULL);
 	g_return_val_if_fail (model && GDA_IS_DATA_MODEL (model), NULL);
 
 	obj = g_object_new (GNOME_DB_MODEL_WRAPPER_TYPE, "dict", ASSERT_DICT (dict), NULL);
@@ -545,6 +544,7 @@ gnome_db_model_wrapper_model_get_new_data_set (GnomeDbDataModel *iface)
 					       gnome_db_base_get_description (GNOME_DB_BASE (list->data)));
 		list = g_slist_next (list);
 	}
+	params = g_slist_reverse (params);
 	data_set = GNOME_DB_DATA_SET (gnome_db_data_set_new (dict, params));
 
 	/* get rid of the params list since we don't use them anymore */
@@ -657,7 +657,7 @@ gnome_db_model_wrapper_get_n_columns (GdaDataModel *model)
 		return -1;
 }
 
-static GdaDataModelColumnAttributes *
+static GdaColumn *
 gnome_db_model_wrapper_describe_column (GdaDataModel *model, gint col)
 {
 	GdaDataModel *gdamodel;
@@ -836,7 +836,7 @@ gnome_db_model_wrapper_update_row (GdaDataModel *model, const GdaRow *row)
 }
 
 static gboolean
-gnome_db_model_wrapper_append_column (GdaDataModel *model, const GdaDataModelColumnAttributes *attrs)
+gnome_db_model_wrapper_append_column (GdaDataModel *model, const GdaColumn *attrs)
 {
 	GdaDataModel *gdamodel;
 	g_return_val_if_fail (IS_GNOME_DB_MODEL_WRAPPER (model), FALSE);
@@ -850,7 +850,7 @@ gnome_db_model_wrapper_append_column (GdaDataModel *model, const GdaDataModelCol
 
 static gboolean
 gnome_db_model_wrapper_update_column (GdaDataModel *model, gint col,
-				      const GdaDataModelColumnAttributes *attrs)
+				      const GdaColumn *attrs)
 {
 	GdaDataModel *gdamodel;
 	g_return_val_if_fail (IS_GNOME_DB_MODEL_WRAPPER (model), FALSE);
@@ -951,7 +951,7 @@ nullified_field_cb (GnomeDbField *field, GnomeDbModelWrapper *wrapper)
 static void
 make_entity_fields (GnomeDbModelWrapper *wrapper)
 {
-	GdaDataModelColumnAttributes *attrs;
+	GdaColumn *attrs;
 
 	if (wrapper->priv->fields)
 		return;
@@ -966,8 +966,8 @@ make_entity_fields (GnomeDbModelWrapper *wrapper)
 			wrapper->priv->fields = g_slist_prepend (wrapper->priv->fields, field);
 
 			attrs = gda_data_model_describe_column (wrapper->priv->model, i);
-			gnome_db_base_set_name (GNOME_DB_BASE (field), attrs->name);
-			gnome_db_base_set_description (GNOME_DB_BASE (field), attrs->caption);
+			gnome_db_base_set_name (GNOME_DB_BASE (field), gda_column_get_name (attrs));
+			gnome_db_base_set_description (GNOME_DB_BASE (field), gda_column_get_caption (attrs));
 
 			gnome_db_base_connect_nullify (field, G_CALLBACK (nullified_field_cb), wrapper);
 		}
@@ -982,21 +982,26 @@ make_entity_fields (GnomeDbModelWrapper *wrapper)
 static gboolean
 gnome_db_wrapper_has_field (GnomeDbEntity *iface, GnomeDbField *field)
 {
-	g_return_val_if_fail (iface && IS_GNOME_DB_MODEL_WRAPPER (iface), FALSE);
-	g_return_val_if_fail (GNOME_DB_MODEL_WRAPPER (iface)->priv, FALSE);
+	GnomeDbModelWrapper *wrapper;
 
-	TO_IMPLEMENT;
-	return FALSE;
+	g_return_val_if_fail (iface && IS_GNOME_DB_MODEL_WRAPPER (iface), FALSE);
+	wrapper = GNOME_DB_MODEL_WRAPPER (iface);
+	g_return_val_if_fail (wrapper->priv, FALSE);
+	
+	return g_slist_find (wrapper->priv->fields, field) ? TRUE : FALSE;
 }
 
 static GSList *
 gnome_db_wrapper_get_fields (GnomeDbEntity *iface)
 {
-	g_return_val_if_fail (iface && IS_GNOME_DB_MODEL_WRAPPER (iface), NULL);
-	g_return_val_if_fail (GNOME_DB_MODEL_WRAPPER (iface)->priv, NULL);
+	GnomeDbModelWrapper *wrapper;
 
-	TO_IMPLEMENT;
-	return NULL;
+	g_return_val_if_fail (iface && IS_GNOME_DB_MODEL_WRAPPER (iface), NULL);
+	wrapper = GNOME_DB_MODEL_WRAPPER (iface);
+	g_return_val_if_fail (wrapper->priv, NULL);
+	make_entity_fields (wrapper);
+	
+	return g_slist_copy (wrapper->priv->fields);
 }
 
 static GnomeDbField *
@@ -1016,41 +1021,52 @@ gnome_db_wrapper_get_field_by_name (GnomeDbEntity *iface, const gchar *name)
 static GnomeDbField *
 gnome_db_wrapper_get_field_by_index (GnomeDbEntity *iface, gint index)
 {
+	GnomeDbModelWrapper *wrapper;
+
 	g_return_val_if_fail (iface && IS_GNOME_DB_MODEL_WRAPPER (iface), NULL);
-	g_return_val_if_fail (GNOME_DB_MODEL_WRAPPER (iface)->priv, NULL);
+	wrapper = GNOME_DB_MODEL_WRAPPER (iface);
+	g_return_val_if_fail (wrapper->priv, NULL);
 	g_return_val_if_fail (index >= 0, NULL);
-	g_return_val_if_fail (index < g_slist_length (GNOME_DB_MODEL_WRAPPER (iface)->priv->fields), NULL);
+	make_entity_fields (wrapper);
+	g_return_val_if_fail (index < g_slist_length (wrapper->priv->fields), NULL);
 	
-	TO_IMPLEMENT;
-	return NULL;
+	return GNOME_DB_FIELD (g_slist_nth_data (wrapper->priv->fields, index));
 }
 
 static gint
 gnome_db_wrapper_get_field_index (GnomeDbEntity *iface, GnomeDbField *field)
 {
-	g_return_val_if_fail (iface && IS_GNOME_DB_MODEL_WRAPPER (iface), -1);
-	g_return_val_if_fail (GNOME_DB_MODEL_WRAPPER (iface)->priv, -1);
+	GnomeDbModelWrapper *wrapper;
 
-	TO_IMPLEMENT;
-	return -1;
+	g_return_val_if_fail (iface && IS_GNOME_DB_MODEL_WRAPPER (iface), -1);
+	wrapper = GNOME_DB_MODEL_WRAPPER (iface);
+	g_return_val_if_fail (wrapper->priv, -1);
+	make_entity_fields (wrapper);
+
+	return g_slist_index (wrapper->priv->fields, field);
 }
 
 
 static gboolean
 gnome_db_wrapper_is_writable (GnomeDbEntity *iface)
 {
+	GnomeDbModelWrapper *wrapper;
+
 	g_return_val_if_fail (iface && IS_GNOME_DB_MODEL_WRAPPER (iface), FALSE);
-	g_return_val_if_fail (GNOME_DB_MODEL_WRAPPER (iface)->priv, FALSE);
-	
-	TO_IMPLEMENT;
+	wrapper = GNOME_DB_MODEL_WRAPPER (iface);
+	g_return_val_if_fail (wrapper->priv, FALSE);
+
 	return FALSE;
 }
 
 static GSList *
 gnome_db_wrapper_get_parameters (GnomeDbEntity *iface)
 {
+	GnomeDbModelWrapper *wrapper;
+
 	g_return_val_if_fail (iface && IS_GNOME_DB_MODEL_WRAPPER (iface), NULL);
-	g_return_val_if_fail (GNOME_DB_MODEL_WRAPPER (iface)->priv, NULL);
+	wrapper = GNOME_DB_MODEL_WRAPPER (iface);
+	g_return_val_if_fail (wrapper->priv, NULL);
 	
 	return NULL;
 }
