@@ -1,9 +1,10 @@
 /* GNOME DB library
- * Copyright (C) 1999-2002 The GNOME Foundation.
+ * Copyright (C) 1999 - 2005 The GNOME Foundation.
  *
  * AUTHORS:
  *      Rodrigo Moya <rodrigo@gnome-db.org>
  *      Carlos Perell Marn <carlos@gnome-db.org>
+ *      Vivien Malerba <malerba@gnome-db.org>
  *
  * This Library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public License as
@@ -59,35 +60,12 @@
 #include <gtk/gtkvpaned.h>
 #include <gtk/gtkvseparator.h>
 #include <gtk/gtkwindow.h>
-#ifdef BUILD_WITH_GNOME
-#include <libgnomedb/gnome-db-browser.h>
-#endif
 #include <libgnomedb/gnome-db-grid.h>
 #include <libgnomedb/gnome-db-util.h>
 #ifdef BUILD_WITH_GNOME
 #include <libgnomeui/gnome-file-entry.h>
 #endif
-#include "gnome-db-i18n.h"
-
-/**
- * gnome_db_new_browser_widget
- *
- *
- *
- * Returns:
- */
-#ifdef BUILD_WITH_GNOME
-GtkWidget *
-gnome_db_new_browser_widget (void)
-{
-	GtkWidget *browser;
-
-	browser = gnome_db_browser_new ();
-	gtk_widget_show (browser);
-
-	return browser;
-}
-#endif
+#include <glib/gi18n-lib.h>
 
 /**
  * gnome_db_new_button_widget
@@ -130,45 +108,6 @@ gnome_db_new_button_widget_from_stock (const gchar *stock_id)
 	return button;
 }
 
-/**
- * gnome_db_new_check_button_widget
- * @label:
- *
- *
- *
- * Returns:
- */
-GtkWidget *
-gnome_db_new_check_button_widget (const gchar *label)
-{
-	GtkWidget *check;
-
-	if (label != NULL)
-		check = gtk_check_button_new_with_label (label);
-	else
-		check = gtk_check_button_new ();
-	gtk_widget_show (check);
-
-	return check;
-}
-
-/**
- * gnome_db_new_combo_widget
- *
- *
- *
- * Returns:
- */
-GtkWidget *
-gnome_db_new_combo_widget (void)
-{
-	GtkWidget *combo;
-
-	combo = gtk_combo_new ();
-	gtk_widget_show (combo);
-
-	return combo;
-}
 
 /**
  * gnome_db_new_entry_widget
@@ -193,78 +132,6 @@ gnome_db_new_entry_widget (gint max_length, gboolean editable)
 	return entry;
 }
 
-#ifdef BUILD_WITH_GNOME
-/**
- * gnome_db_new_file_entry_widget
- * @history_id:
- * @title:
- *
- *
- *
- * Returns:
- */
-GtkWidget *
-gnome_db_new_file_entry_widget (const gchar *history_id, const gchar *title)
-{
-	GtkWidget *entry;
-#if GTK_CHECK_VERSION(2,4,0)
-	GValue value = { 0, };
-#endif
-
-	entry = gnome_file_entry_new (history_id, title);
-#if GTK_CHECK_VERSION(2, 4, 0)
-	g_value_init (&value, G_TYPE_BOOLEAN);
-	g_value_set_boolean (&value, TRUE);
-	g_object_set_property (G_OBJECT (entry), "use-filechooser", &value);
-	g_value_reset (&value);
-#endif
-	gtk_widget_show (entry);
-
-	return entry;
-}
-#endif
-
-/**
- * gnome_db_new_frame_widget
- * @title:
- *
- *
- *
- * Returns:
- */
-GtkWidget *
-gnome_db_new_frame_widget (const gchar *title)
-{
-	GtkWidget *frame;
-
-	frame = gtk_frame_new (title);
-	gtk_widget_show (frame);
-
-	return frame;
-}
-
-/**
- * gnome_db_new_grid_widget
- * @model:
- *
- *
- *
- * Returns:
- */
-GtkWidget *
-gnome_db_new_grid_widget (GdaDataModel *model)
-{
-	GtkWidget *grid;
-
-	if (GDA_IS_DATA_MODEL (model))
-		grid = gnome_db_grid_new_with_model (model);
-	else
-		grid = gnome_db_grid_new ();
-	gtk_widget_show (grid);
-
-	return grid;
-}
-
 /**
  * gnome_db_new_hbox_widget
  * @homogenous:
@@ -285,60 +152,6 @@ gnome_db_new_hbox_widget (gboolean homogenous, gint spacing)
 	return hbox;
 }
 
-/**
- * gnome_db_new_hbutton_box_widget
- *
- *
- *
- * Returns: 
- */
-GtkWidget *
-gnome_db_new_hbutton_box_widget (void)
-{
-	GtkWidget *hbbox;
-
-	hbbox = gtk_hbutton_box_new ();
-	gtk_widget_show (hbbox);
-
-	return hbbox;
-}
-
-/**
- * gnome_db_new_hpaned_widget
- *
- *
- *
- * Returns:
- */
-GtkWidget *
-gnome_db_new_hpaned_widget (void)
-{
-	GtkWidget *hpaned;
-
-	hpaned = gtk_hpaned_new ();
-	gtk_widget_show (hpaned);
-
-	return hpaned;
-}
-
-/**
- * gnome_db_new_hseparator_widget
- *
- *
- *
- * Returns:
- */
-GtkWidget *
-gnome_db_new_hseparator_widget (void)
-{
-	GtkWidget *hsep;
-
-	hsep = gtk_hseparator_new ();
-	gtk_widget_show (hsep);
-
-	return hsep;
-}
-
 /**
  * gnome_db_new_label_widget
  * @text:
@@ -381,70 +194,6 @@ gnome_db_new_notebook_widget (void)
 	return notebook;
 }
 
-/**
- * gnome_db_new_option_menu_widget
- *
- *
- *
- * Returns:
- */
-GtkWidget *
-gnome_db_new_option_menu_widget (void)
-{
-	GtkWidget *option_menu;
-
-	option_menu = gtk_option_menu_new ();
-	gtk_widget_show (option_menu);
-
-	return option_menu;
-}
-
-#ifdef BUILD_WITH_GNOME
-/**
- * gnome_db_new_popup_menu
- * @parent:
- * @ui_info:
- * @user_data:
- *
- *
- *
- * Returns:
- */
-GtkWidget *
-gnome_db_new_popup_menu (GtkWidget *parent, GnomeUIInfo *ui_info, gpointer user_data)
-{
-	GtkWidget *popup_menu;
-
-        g_return_val_if_fail (parent != NULL, NULL);
-        g_return_val_if_fail (ui_info != NULL, NULL);
-
-        popup_menu = gnome_popup_menu_new (ui_info);
-        gnome_popup_menu_attach (popup_menu, parent, user_data);
-
-        return popup_menu;
-}
-#endif
-
-/**
- * gnome_db_new_radio_button_widget
- * @group:
- * @label:
- *
- *
- *
- * Returns:
- */
-GtkWidget *
-gnome_db_new_radio_button_widget (GSList *group, const gchar *label)
-{
-	GtkWidget *radio;
-
-	radio = gtk_radio_button_new_with_label (group, label);
-	gtk_widget_show (radio);
-
-	return radio;
-}
-
 /**
  * gnome_db_new_scrolled_window_widget
  *
@@ -468,24 +217,6 @@ gnome_db_new_scrolled_window_widget (void)
 	return scroll;
 }
 
-/**
- * gnome_db_new_status_bar_widget
- *
- *
- *
- * Returns:
- */
-GtkWidget *
-gnome_db_new_status_bar_widget (void)
-{
-        GtkWidget* status;
-
-        status = gtk_statusbar_new ();
-        gtk_widget_show (status);
-
-        return status;
-}
-
 /**
  * gnome_db_new_table_widget
  * @rows:
@@ -538,28 +269,6 @@ gnome_db_new_text_widget (const gchar *contents)
 	return text;
 }
 
-/**
- * gnome_db_new_toolbar_widget
- * @orientation:
- * @style:
- *
- *
- *
- * Returns:
- */
-GtkWidget *
-gnome_db_new_toolbar_widget (GtkOrientation orientation, GtkToolbarStyle style)
-{
-	GtkWidget *toolbar;
-
-	toolbar = gtk_toolbar_new ();
-	gtk_toolbar_set_orientation (GTK_TOOLBAR (toolbar), orientation);
-	gtk_toolbar_set_style (GTK_TOOLBAR (toolbar), style);
-	gtk_widget_show (toolbar);
-
-	return toolbar;
-}
-
 /**
  * gnome_db_new_tree_view_widget
  * @model:
@@ -602,75 +311,6 @@ gnome_db_new_vbox_widget (gboolean homogenous, gint spacing)
 	return vbox;
 }
 
-/**
- * gnome_db_new_vpaned_widget
- *
- *
- *
- * Returns:
- */
-GtkWidget *
-gnome_db_new_vpaned_widget (void)
-{
-	GtkWidget *vpaned;
-
-	vpaned = gtk_vpaned_new ();
-	gtk_widget_show (vpaned);
-
-	return vpaned;
-}
-
-/**
- * gnome_db_new_vseparator_widget
- *
- *
- *
- * Returns:
- */
-GtkWidget *
-gnome_db_new_vseparator_widget (void)
-{
-	GtkWidget *sep;
-
-	sep = gtk_vseparator_new ();
-	gtk_widget_show (sep);
-
-	return sep;
-}
-
-/**
- * gnome_db_set_widget_bg_color
- * @widget:
- * @color:
- *
- */
-void
-gnome_db_set_widget_bg_color (GtkWidget *widget, const gchar *color)
-{
-	GdkColor gdk_color;
-
-	g_return_if_fail (GTK_IS_WIDGET (widget));
-
-	gdk_color_parse (color, &gdk_color);
-	gtk_widget_modify_bg (widget, GTK_STATE_NORMAL, &gdk_color);
-}
-
-/**
- * gnome_db_set_widget_fg_color
- * @widget:
- * @color:
- *
- */
-void
-gnome_db_set_widget_fg_color (GtkWidget *widget, const gchar *color)
-{
-	GdkColor gdk_color;
-
-	g_return_if_fail (GTK_IS_WIDGET (widget));
-
-	gdk_color_parse (color, &gdk_color);
-	gtk_widget_modify_fg (widget, GTK_STATE_NORMAL, &gdk_color);
-}
 
 /**
  * gnome_db_option_menu_add_item
